# Welcome to cmip6_aws


[![image](https://img.shields.io/pypi/v/cmip6_aws.svg)](https://pypi.python.org/pypi/cmip6_aws)


**download data from NASA Earth Exchange Global Daily Downscaled Projections (NEX-GDDP-CMIP6)**


-   Free software: MIT License
-   Documentation: <https://advancehs.github.io/cmip6_aws>
    

## Features

-   TODO
